@@ -22,7 +22,7 @@
 #include <KompareDiff2/DiffModel>
 #include <KompareDiff2/DiffHunk>
 #include <KompareDiff2/Difference>
-#include <KompareDiff2/KompareModelList>
+#include <KompareDiff2/ModelList>
 
 #include <komparepartdebug.h>
 #include "viewsettings.h"
@@ -36,7 +36,7 @@
 
 #define ITEM_MARGIN 3
 
-using namespace Diff2;
+using namespace KompareDiff2;
 
 KompareListViewFrame::KompareListViewFrame(bool isSource,
                                            ViewSettings* settings,
@@ -362,8 +362,9 @@ void KompareListView::slotSetSelection(const DiffModel* model, const Difference*
     m_itemDict.clear();
     m_selectedModel = model;
 
-    DiffHunkListConstIterator hunkIt = model->hunks()->begin();
-    DiffHunkListConstIterator hEnd   = model->hunks()->end();
+    const DiffHunkList* hunks = model->hunks();
+    DiffHunkListConstIterator hunkIt = hunks->begin();
+    DiffHunkListConstIterator hEnd   = hunks->end();
 
     KompareListViewItem* item = nullptr;
     m_nextPaintOffset = 0;
@@ -375,8 +376,9 @@ void KompareListView::slotSetSelection(const DiffModel* model, const Difference*
         else
             item = new KompareListViewHunkItem(this, *hunkIt, model->isBlended());
 
-        DifferenceListConstIterator diffIt = (*hunkIt)->differences().begin();
-        DifferenceListConstIterator dEnd   = (*hunkIt)->differences().end();
+        const DifferenceList differences = (*hunkIt)->differences();
+        DifferenceListConstIterator diffIt = differences.begin();
+        DifferenceListConstIterator dEnd   = differences.end();
 
         for (; diffIt != dEnd; ++diffIt)
         {
@@ -469,8 +471,8 @@ void KompareListView::slotApplyDifference(bool apply)
 
 void KompareListView::slotApplyAllDifferences(bool apply)
 {
-    QHash<const Diff2::Difference*, KompareListViewDiffItem*>::ConstIterator it = m_itemDict.constBegin();
-    QHash<const Diff2::Difference*, KompareListViewDiffItem*>::ConstIterator end = m_itemDict.constEnd();
+    QHash<const KompareDiff2::Difference*, KompareListViewDiffItem*>::ConstIterator it = m_itemDict.constBegin();
+    QHash<const KompareDiff2::Difference*, KompareListViewDiffItem*>::ConstIterator end = m_itemDict.constEnd();
     for (; it != end; ++it)
         it.value()->applyDifference(apply);
 
@@ -812,10 +814,11 @@ void KompareListViewLineItem::paintText(QPainter* p, const QColor& bg, int colum
 
         p->fillRect(0, 0, offset, paintHeight(), normalBrush);
 
-        if (!m_text->markerList().isEmpty())
+        const MarkerList markerList = m_text->markerList();
+        if (!markerList.isEmpty())
         {
-            MarkerListConstIterator markerIt = m_text->markerList().begin();
-            MarkerListConstIterator mEnd     = m_text->markerList().end();
+            MarkerListConstIterator markerIt = markerList.begin();
+            MarkerListConstIterator mEnd     = markerList.end();
             Marker* m = *markerIt;
 
             for (; markerIt != mEnd; ++markerIt)
